DestinationBuilder

Trait DestinationBuilder 

pub trait DestinationBuilder: MemoryBounds {
    // Required methods
    fn input_event_type(&self) -> EventType;
    fn build<'life0, 'async_trait>(
        &'life0 self,
        context: ComponentContext,
    ) -> Pin<Box<dyn Future<Output = Result<Box<dyn Destination + Send>, GenericError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
A destination builder.

Destination builders are responsible for creating instances of Destinations, as well as describing high-level aspects of the built destination, such as the data types allowed for input events.

Required Methods

fn input_event_type(&self) -> EventType

Event types allowed as input events to this destination.

fn build<'life0, 'async_trait>( &'life0 self, context: ComponentContext, ) -> Pin<Box<dyn Future<Output = Result<Box<dyn Destination + Send>, GenericError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Builds an instance of the destination.

Errors

If the destination can’t be built for any reason, an error is returned.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors